@@ -1,5 +1,8 @@
 from __future__ import absolute_import
 
+# This file is excluded from flake8 checking in setup.cfg
+
+from .actions import *
 from .axes import *
 from .formatters import *
 from .glyphs import *
