@@ -18,6 +18,16 @@ class Ticker(PlotObject):
     adjacent major tick values.
     """)
 
+    desired_num_ticks = Int(6, help="""
+    A desired target number of major tick positions to generate across
+    the plot range.
+
+    .. note:
+        This value is a suggestion, and ticker subclasses may ignore
+        it entirely, or use it only as an ideal goal to approach as well
+        as can be, in the context of a specific ticking strategy.
+    """)
+
 class AdaptiveTicker(Ticker):
     """ Generate "nice" round ticks at any magnitude.
 
