@@ -4,13 +4,15 @@
 #
 # Powered by the Bokeh Development Team.
 #
-# The full license is in the file LICENCE.txt, distributed with this software.
+# The full license is in the file LICENSE.txt, distributed with this software.
 #-----------------------------------------------------------------------------
 
 #-----------------------------------------------------------------------------
 # Imports
 #-----------------------------------------------------------------------------
 
+from __future__ import absolute_import
+
 import itertools
 import warnings
 
@@ -19,8 +21,8 @@ import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
 
-from .models.glyphs import (Asterisk, Circle, Cross, Diamond, InvertedTriangle, Line,
-                            MultiLine, Patches, Square, Text, Triangle, X)
+from .models.glyphs import (Asterisk, Circle, Cross, Diamond, InvertedTriangle,
+                            Line, MultiLine, Patches, Square, Text, Triangle, X)
 from .mplexporter.exporter import Exporter
 from .mplexporter.renderers import Renderer
 from .mpl_helpers import (convert_dashes, delete_last_col, get_props_cycled,
@@ -29,7 +31,11 @@ from .models import (ColumnDataSource, DataRange1d, DatetimeAxis, GlyphRenderer,
                      Grid, GridPlot, LinearAxis, PanTool, Plot, PreviewSaveTool,
                      ResetTool, WheelZoomTool)
 from .plotting import (curdoc, output_file, output_notebook, output_server,
-                       show)
+                       DEFAULT_TOOLS)
+from .plotting_helpers import _process_tools_arg
+
+# Names that we want in this namespace (fool pyflakes)
+(PanTool, ResetTool, PreviewSaveTool, WheelZoomTool)
 
 #-----------------------------------------------------------------------------
 # Classes and functions
@@ -43,7 +49,6 @@ class BokehRenderer(Renderer):
         self.fig = None
         self.pd_obj = pd_obj
         self.xkcd = xkcd
-        self.source = ColumnDataSource()
         self.xdr = DataRange1d()
         self.ydr = DataRange1d()
         self.non_text = [] # to save the text we don't want to convert by draw_text
@@ -60,11 +65,8 @@ class BokehRenderer(Renderer):
     def close_figure(self, fig):
         "Complete the plot: add tools."
         # Add tools
-        pan = PanTool()
-        wheelzoom = WheelZoomTool()
-        reset = ResetTool()
-        previewsave = PreviewSaveTool()
-        self.plot.add_tools(pan, wheelzoom, reset, previewsave)
+        tool_objs = _process_tools_arg(self.plot, DEFAULT_TOOLS)
+        self.plot.add_tools(*tool_objs)
 
         # Simple or Grid plot setup
         if len(fig.axes) <= 1:
@@ -83,11 +85,8 @@ class BokehRenderer(Renderer):
                              plot_height=self.height)
                 _plot.title = ""
                 # and add new tools
-                _pan = PanTool()
-                _wheelzoom = WheelZoomTool()
-                _reset = ResetTool()
-                _previewsave = PreviewSaveTool()
-                _plot.add_tools(_pan, _wheelzoom, _reset, _previewsave)
+                _tool_objs = _process_tools_arg(_plot, DEFAULT_TOOLS)
+                _plot.add_tools(*_tool_objs)
                 # clean the plot ref from axis and grids
                 _plot_rends = subrends[i]
                 for r in _plot_rends:
@@ -159,7 +158,7 @@ class BokehRenderer(Renderer):
         if self.pd_obj is True:
             try:
                 x = [pd.Period(ordinal=int(i), freq=self.ax.xaxis.freq).to_timestamp() for i in _x]
-            except AttributeError as e: #  we probably can make this one more intelligent later
+            except AttributeError: #  we probably can make this one more intelligent later
                 x = _x
         else:
             x = _x
@@ -169,10 +168,9 @@ class BokehRenderer(Renderer):
             x, y = xkcd_line(x, y)
 
         line = Line()
-        line.x = self.source.add(x)
-        line.y = self.source.add(y)
-        self.xdr.sources.append(self.source.columns(line.x))
-        self.ydr.sources.append(self.source.columns(line.y))
+        source = ColumnDataSource()
+        line.x = source.add(x)
+        line.y = source.add(y)
 
         line.line_color = style['color']
         line.line_width = style['linewidth']
@@ -184,7 +182,7 @@ class BokehRenderer(Renderer):
         if self.xkcd:
             line.line_width = 3
 
-        self.plot.add_glyph(self.source, line)
+        self.plot.add_glyph(source, line)
 
     def draw_markers(self, data, coordinates, style, label, mplobj=None):
         "Given a mpl line2d instance create a Bokeh Marker glyph."
@@ -201,14 +199,17 @@ class BokehRenderer(Renderer):
             "D": Diamond,
             "*": Asterisk,
         }
-        if style['marker'] not in marker_map:
-            warnings.warn("Unable to handle marker: %s" % style['marker'])
 
-        marker = marker_map[style['marker']]()
-        marker.x = self.source.add(x)
-        marker.y = self.source.add(y)
-        self.xdr.sources.append(self.source.columns(marker.x))
-        self.ydr.sources.append(self.source.columns(marker.y))
+        # Not all matplotlib markers are currently handled; fall back to Circle if we encounter an
+        # unhandled marker.  See http://matplotlib.org/api/markers_api.html for a list of markers.
+        try:
+            marker = marker_map[style['marker']]()
+        except KeyError:
+            warnings.warn("Unable to handle marker: %s; defaulting to Circle" % style['marker'])
+            marker = Circle()
+        source = ColumnDataSource()
+        marker.x = source.add(x)
+        marker.y = source.add(y)
 
         marker.line_color = style['edgecolor']
         marker.fill_color = style['facecolor']
@@ -217,7 +218,7 @@ class BokehRenderer(Renderer):
         marker.fill_alpha = marker.line_alpha = style['alpha']
         #style['zorder'] # not in Bokeh
 
-        self.plot.add_glyph(self.source, marker)
+        self.plot.add_glyph(source, marker)
 
     def draw_path_collection(self, paths, path_coordinates, path_transforms,
                              offsets, offset_coordinates, offset_order,
@@ -235,29 +236,30 @@ class BokehRenderer(Renderer):
         # inside the plot itself. That does not make sense inside Bokeh, so we
         # just skip the title and axes names from the conversion and covert any other text.
         if text not in self.non_text:
-          x, y = position
-          text = Text(x=x, y=y, text=[text])
+            x, y = position
+            text = Text(x=x, y=y, text=[text])
 
-          alignment_map = {"center": "middle", "top": "top", "bottom": "bottom", "baseline": "bottom"}
-          # baseline not implemented in Bokeh, deafulting to bottom.
-          text.text_alpha = style['alpha']
-          text.text_font_size = "%dpx" % style['fontsize']
-          text.text_color = style['color']
-          text.text_align = style['halign']
-          text.text_baseline = alignment_map[style['valign']]
-          text.angle = style['rotation']
-          #style['zorder'] # not in Bokeh
+            alignment_map = {"center": "middle", "top": "top", "bottom": "bottom", "baseline": "bottom"}
+            # baseline not implemented in Bokeh, deafulting to bottom.
+            text.text_alpha = style['alpha']
+            text.text_font_size = "%dpx" % style['fontsize']
+            text.text_color = style['color']
+            text.text_align = style['halign']
+            text.text_baseline = alignment_map[style['valign']]
+            text.angle = style['rotation']
+            #style['zorder'] # not in Bokeh
 
-          ## Using get_fontname() works, but it's oftentimes not available in the browser,
-          ## so it's better to just use the font family here.
-          #text.text_font = mplText.get_fontname()) not in mplexporter
-          #text.text_font = mplText.get_fontfamily()[0] # not in mplexporter
-          #text.text_font_style = fontstyle_map[mplText.get_fontstyle()] # not in mplexporter
-          ## we don't really have the full range of font weights, but at least handle bold
-          #if mplText.get_weight() in ("bold", "heavy"):
-              #text.text_font_style = bold
+            ## Using get_fontname() works, but it's oftentimes not available in the browser,
+            ## so it's better to just use the font family here.
+            #text.text_font = mplText.get_fontname()) not in mplexporter
+            #text.text_font = mplText.get_fontfamily()[0] # not in mplexporter
+            #text.text_font_style = fontstyle_map[mplText.get_fontstyle()] # not in mplexporter
+            ## we don't really have the full range of font weights, but at least handle bold
+            #if mplText.get_weight() in ("bold", "heavy"):
+                #text.text_font_style = bold
 
-          self.plot.add_glyph(self.source, text)
+            source = ColumnDataSource()
+            self.plot.add_glyph(source, text)
 
     def draw_image(self, imdata, extent, coordinates, style, mplobj=None):
         pass
@@ -326,14 +328,13 @@ class BokehRenderer(Renderer):
             ys = xkcd_ys
 
         multiline = MultiLine()
-        multiline.xs = self.source.add(xs)
-        multiline.ys = self.source.add(ys)
-        self.xdr.sources.append(self.source.columns(multiline.xs))
-        self.ydr.sources.append(self.source.columns(multiline.ys))
+        source = ColumnDataSource()
+        multiline.xs = source.add(xs)
+        multiline.ys = source.add(ys)
 
-        self.multiline_props(multiline, col)
+        self.multiline_props(source, multiline, col)
 
-        self.plot.add_glyph(self.source, multiline)
+        self.plot.add_glyph(source, multiline)
 
     def make_poly_collection(self, col):
         "Given a mpl collection instance create a Bokeh Patches glyph."
@@ -344,21 +345,20 @@ class BokehRenderer(Renderer):
         ys = [polygons[i][1] for i in range(len(polygons))]
 
         patches = Patches()
-        patches.xs = self.source.add(xs)
-        patches.ys = self.source.add(ys)
-        self.xdr.sources.append(self.source.columns(patches.xs))
-        self.ydr.sources.append(self.source.columns(patches.ys))
+        source = ColumnDataSource()
+        patches.xs = source.add(xs)
+        patches.ys = source.add(ys)
 
-        self.patches_props(patches, col)
+        self.patches_props(source, patches, col)
 
-        self.plot.add_glyph(self.source, patches)
+        self.plot.add_glyph(source, patches)
 
-    def multiline_props(self, multiline, col):
+    def multiline_props(self, source, multiline, col):
         "Takes a mpl collection object to extract and set up some Bokeh multiline properties."
         colors = get_props_cycled(col, col.get_colors(), fx=lambda x: mpl.colors.rgb2hex(x))
         widths = get_props_cycled(col, col.get_linewidth())
-        multiline.line_color = self.source.add(colors)
-        multiline.line_width = self.source.add(widths)
+        multiline.line_color = source.add(colors)
+        multiline.line_width = source.add(widths)
         multiline.line_alpha = col.get_alpha()
         offset = col.get_linestyle()[0][0]
         if not col.get_linestyle()[0][1]:
@@ -368,15 +368,16 @@ class BokehRenderer(Renderer):
         multiline.line_dash_offset = convert_dashes(offset)
         multiline.line_dash = list(convert_dashes(tuple(on_off)))
 
-    def patches_props(self, patches, col):
+    def patches_props(self, source, patches, col):
         "Takes a mpl collection object to extract and set up some Bokeh patches properties."
         face_colors = get_props_cycled(col, col.get_facecolors(), fx=lambda x: mpl.colors.rgb2hex(x))
-        patches.fill_color = self.source.add(face_colors)
+        patches.fill_color = source.add(face_colors)
         edge_colors = get_props_cycled(col, col.get_edgecolors(), fx=lambda x: mpl.colors.rgb2hex(x))
-        patches.line_color = self.source.add(edge_colors)
+        patches.line_color = source.add(edge_colors)
         widths = get_props_cycled(col, col.get_linewidth())
-        patches.line_width = self.source.add(widths)
+        patches.line_width = source.add(widths)
         patches.line_alpha = col.get_alpha()
+        patches.fill_alpha = col.get_alpha()
         offset = col.get_linestyle()[0][0]
         if not col.get_linestyle()[0][1]:
             on_off = []
@@ -386,8 +387,7 @@ class BokehRenderer(Renderer):
         patches.line_dash = list(convert_dashes(tuple(on_off)))
 
 
-def to_bokeh(fig=None, name=None, server=None, notebook=False, pd_obj=True,
-             xkcd=False):
+def to_bokeh(fig=None, name=None, server=None, notebook=False, pd_obj=True, xkcd=False):
     """ Uses bokeh to display a Matplotlib Figure.
 
     You can store a bokeh plot in a standalone HTML file, as a document in
@@ -403,7 +403,7 @@ def to_bokeh(fig=None, name=None, server=None, notebook=False, pd_obj=True,
 
     name: str (default=None)
         If this option is provided, then the Bokeh figure will be saved into
-        this HTML file, and then a web browser will used to display it.
+        this HTML file, and then a web browser will be used to display it.
 
     server: str (default=None)
         Fully specified URL of bokeh plot server. Default bokeh plot server
@@ -454,4 +454,4 @@ def to_bokeh(fig=None, name=None, server=None, notebook=False, pd_obj=True,
     doc._current_plot = renderer.fig  # TODO (bev) do not rely on private attrs
     doc.add(renderer.fig)
 
-    show()
+    return renderer.fig
