@@ -1,11 +1,13 @@
-
 from collections import OrderedDict
+
 import numpy as np
 import pandas as pd
-from bokeh.plotting import *
+
+from bokeh.plotting import figure, show, output_file
+from bokeh.palettes import brewer
 
 N = 20
-categories = ['y' + str(x) for x in xrange(10)]
+categories = ['y' + str(x) for x in range(10)]
 data = {}
 data['x'] = np.arange(N)
 for cat in categories:
@@ -23,14 +25,16 @@ def stacked(df, categories):
         last = next
     return areas
 
-output_file("brewer.html", title="brewer.py example")
-
 areas = stacked(df, categories)
 
 colors = brewer["Spectral"][len(areas)]
 
 x2 = np.hstack((data['x'][::-1], data['x']))
-patches([x2 for a in areas], areas.values(), color=colors, alpha=0.8, line_color=None)
 
-show()
+output_file("brewer.html", title="brewer.py example")
 
+p = figure()
+p.patches([x2 for a in areas], list(areas.values()), color=colors, alpha=0.8, line_color=None)
+
+p.grid.minor_grid_line_color = '#eeeeee'
+show(p)
