@@ -1,9 +1,7 @@
 # The plot server must be running
 # Go to http://localhost:5006/bokeh to view this plot
 
-import numpy as np
-from bokeh.plotting import *
-from bokeh.models import ServerDataSource, BlazeDataSource
+from bokeh.plotting import figure, show, output_server
 from bokeh.transforms import line_downsample
 from blaze.server.client import Client
 from blaze import Data
